
#delimit ;
version 8.0;
set more off;

************************************************************;
*** NOTE: FOR THIS CODE TO RUN, YOU MUST DOWNLOAD THE    ***;
*** DATA FILES SEPARATELY FROM THE WEBSITES REFERENCED   ***;
*** BELOW, AND THEN CHANGE THE DIRECTORY LOCATION IN THE ***;
*** NEXT LINE TO THE FOLDER HOLDING THE SAVED FILES      ***;
************************************************************;

cd "C:\Projects\WarrenTroyJCR\";

*********************;
*** LOAD MAR DATA ***;
*********************;

*************************;
*** A. LOAD BASE FILE ***;
*************************;

insheet using "mardatav02.2005.csv", comma clear; 

**********************************************************;
*** Accessed at: http://www.cidcm.umd.edu/mar/data.asp ***;
*** 4/26/2011                                          ***;
**********************************************************;

keep 	reb numcode group ccode country year gpro 
		intracon fccs1 fccs2 fccs3 fccs4 
		atrisk1 atrisk2 atrisk3 atrisk4 
		lang belief race gojpa gc10 ;

order 	numcode group ccode country year gpro 
		reb intracon fccs1 fccs2 fccs3 fccs4 
		atrisk1 atrisk2 atrisk3 atrisk4 
		lang belief race gojpa gc10 ;

rename lang lang_mar1;
rename belief belief_mar1;
rename race race_mar1;
rename gojpa gojpa_mar1;
rename gc10 gc10_mar1;

mvdecode _all, mv(-99);

***************************;
*** TEMP SAVE BASE FILE ***;
***************************;

tempfile mar1;
save "`mar1'";  

***************************;
*** B. LOAD 2006 UPDATE ***;
***************************;

use "marupdate_20042006.dta", clear;

**********************************************************;
*** Accessed at: http://www.cidcm.umd.edu/mar/data.asp ***;
*** 4/26/2011                                          ***;
**********************************************************;

rename VMAR_Group group;
rename GPRO gpro;
rename LANG lang;
rename BELIEF belief;
rename RACE race;
rename GC10 gc10;
rename GOJPA gojpa;
rename INTRACON intracon;
rename FACTSEV1 fccs1;
rename FACTSEV2 fccs2;
rename FACTSEV3 fccs3;
rename REB reb;

keep 	reb numcode group ccode country year gpro 
		intracon fccs1 fccs2 fccs3 
		lang belief race gojpa gc10;

order 	reb numcode group ccode country year gpro 
		intracon fccs1 fccs2 fccs3 
		lang belief race gojpa gc10;
		
rename lang lang_mar2;
rename belief belief_mar2;
rename race race_mar2;
rename gojpa gojpa_mar2;
rename gc10 gc10_mar2;
		
destring fccs2 fccs3, replace;
mvdecode _all, mv(-99);

*****************************;
*** TEMP SAVE 2006 UPDATE ***;
*****************************;

tempfile mar2;
save "`mar2'";


***************************************;
*** MERGE BASE FILE AND 2006 UPDATE ***;
***************************************;

use "`mar1'", clear; 
append using "`mar2'";


*****************;
*** FIX TYPOS ***;
*****************;

replace numcode = 53004 if group == "OROMO" & numcode == 53001;
drop if group == "DARFUR BLACK MUSLIMS" & year == 2004;
drop if group == "KURDS" & year == 2004;

label drop _all;

label variable race_mar2;
label variable belief_mar2;
label variable lang_mar2;
label variable gojpa_mar2;
label variable gc10_mar2;

label values race_mar2;
label values belief_mar2;
label values lang_mar2;
label values gojpa_mar2;
label values gc10_mar2;

keep if year >= 1985;
sort numcode year;


***********************************;
*** GENERATE DEPENDENT VARIABLE ***;
***********************************;

gen intrawar = 0;
replace intrawar = 1 if 
	(fccs1 >= 3 & fccs1 != .) | 
	(fccs2 >= 3 & fccs2 != .) | 
	(fccs3 >= 3 & fccs3 != .) | 
	(fccs4 >= 3 & fccs4 != .);

	
**************************************;
*** GENERATE INDEPENDENT VARIABLES ***;
**************************************;	

******************;
*** Group Size ***;
******************;
by numcode: ipolate gpro year, gen(gpro_temp);
gen float gpro_i = round(gpro_temp, 0.0001);
drop gpro_temp;

gen gpro2_i = gpro_i * gpro_i;


******************************;
*** Conflict History (Splines);
******************************;
btscs intrawar year numcode if year >= 1990, gen(pcyrs) nspline(3);
**********************************************************;
*** BTSCS SOFTWARE                                     ***
*** Accessed at: http://www.prio.no/Data/Stata-Tools/  ***;
*** 5/30/2011                                          ***;
**********************************************************;

rename _spline1 spline1;
rename _spline2 spline2;
rename _spline3 spline3;

gen pcyrs2 = pcyrs * pcyrs;
gen pcyrs3 = pcyrs * pcyrs * pcyrs;

************;
*** Race ***;
************;
gen race_bin_mar1 = 0     if race_mar1 != .;
replace race_bin_mar1 = 1 if race_mar1 == 1 | 
							 race_mar1 == 2 | 
							 race_mar1 == 3;
by numcode: egen maxrace_bin_mar1 = max(race_bin_mar1);

gen race_bin_mar2 = 0     if race_mar2 != .;
replace race_bin_mar2 = 1 if race_mar2 == 1 | 
							 race_mar2 == 2 | 
							 race_mar2 == 3;
by numcode: egen maxrace_bin_mar2 = max(race_bin_mar2);

gen race_bin = maxrace_bin_mar2;
replace race_bin = maxrace_bin_mar1 if race_bin == .;

****************;
*** Religion ***;
****************;
gen belief_bin_mar1 = 0     if belief_mar1 != .;
replace belief_bin_mar1 = 1 if belief_mar1 == 1 | 
							   belief_mar1 == 3;
by numcode: egen maxbelief_bin_mar1 = max(belief_bin_mar1);

gen belief_bin_mar2 = 0     if belief_mar2 != .;
replace belief_bin_mar2 = 1 if belief_mar2 == 1 | 
							   belief_mar2 == 2;
by numcode: egen maxbelief_bin_mar2 = max(belief_bin_mar2);

gen belief_bin = maxbelief_bin_mar2;
replace belief_bin = maxbelief_bin_mar1 if belief_bin == .;

****************;
*** Language ***;
****************;
gen lang_bin_mar1 = 0     if lang_mar1 != .;
replace lang_bin_mar1 = 1 if lang_mar1 == 1;
by numcode: egen maxlang_bin_mar1 = max(lang_bin_mar1);

gen lang_bin_mar2 = 0     if lang_mar2 != .;
replace lang_bin_mar2 = 1 if lang_mar2 == 2;
by numcode: egen maxlang_bin_mar2 = max(lang_bin_mar2);

gen lang_bin = maxlang_bin_mar2;
replace lang_bin = maxlang_bin_mar1 if lang_bin == .;

********************************;
*** Transnational Dispersion ***;
********************************;
gen transnat_bin_mar1 = 0     if gc10_mar1 != .;
replace transnat_bin_mar1 = 1 if gc10_mar1 == 2 | 
								 gc10_mar1 == 3 | 
								 gc10_mar1 == 4 | 
								 gc10_mar1 == 5;
by numcode: egen maxtransnat_bin_mar1 = max(transnat_bin_mar1);
								 
gen transnat_bin_mar2 = 0     if gc10_mar2 != .;
replace transnat_bin_mar2 = 1 if gc10_mar2 == 1 | 
								 gc10_mar2 == 2 | 
								 gc10_mar2 == 3;
by numcode: egen maxtransnat_bin_mar2 = max(transnat_bin_mar2);

gen transnat_bin = maxtransnat_bin_mar2;
replace transnat_bin = maxtransnat_bin_mar1 if transnat_bin == .;

*****************************;
*** Militant Organization ***;
*****************************;
gen gojpa_bin_mar1 = 0     if gojpa_mar1 != .;
replace gojpa_bin_mar1 = 1 if gojpa_mar1 == 3 | 
							  gojpa_mar1 == 4 | 
							  gojpa_mar1 == 5;
by numcode: egen maxgojpa_bin_mar1 = max(gojpa_bin_mar1);

gen gojpa_bin_mar2 = 0     if gojpa_mar2 != .;
replace gojpa_bin_mar2 = 1 if gojpa_mar2 == 3 | 
							  gojpa_mar2 == 4 | 
							  gojpa_mar2 == 5;
by numcode: egen maxgojpa_bin_mar2 = max(gojpa_bin_mar2);

gen gojpa_bin = maxgojpa_bin_mar2;
replace gojpa_bin = maxgojpa_bin_mar1 if gojpa_bin == .;


drop  	lang_bin_mar1 maxlang_bin_mar1
		lang_bin_mar2 maxlang_bin_mar2 
		belief_bin_mar1 maxbelief_bin_mar1  
		belief_bin_mar2 maxbelief_bin_mar2 
		race_bin_mar1 maxrace_bin_mar1
		race_bin_mar2 maxrace_bin_mar2 
		transnat_bin_mar1 maxtransnat_bin_mar1 
		transnat_bin_mar2 maxtransnat_bin_mar2 
		gojpa_bin_mar1 maxgojpa_bin_mar1
		gojpa_bin_mar2 maxgojpa_bin_mar2 ;
		


*****************;
*** Rebellion ***;
*****************;
sort numcode year;
gen reb_lag5 = 0;
replace reb_lag5 = 1 if reb[_n-1] >= 4 | 
						reb[_n-2] >= 4 | 
						reb[_n-3] >= 4 | 
						reb[_n-4] >= 4 | 
						reb[_n-5] >= 4;
replace reb_lag5 = . if year < 1990;		
		
		
************************;
*** Population & GDP ***;
************************;		
joinby ccode year using 
"pwt63.cow.dta", 
unmatched(master) _merge(_merge_pwt);

*******************************************************;
*** Population & GDP Data                           ***;
*** Accessed from Penn World Tables, v.6.3          ***;
*** https://pwt.sas.upenn.edu/                      ***;
*** 12/9/2010                                       ***;
*** (Edited by author to include COW country codes) ***;
*******************************************************;

gen lgdpl = log(gdpl);
gen lpopl = log(popl);

***************;
*** XPolity ***;
***************;
joinby ccode year using 
"xpolity.cow.dta", 
unmatched(master) _merge(_merge_xpol);
***************************************************************;
*** Regime Type Compenent Data                              ***;
*** Accessed from Polity IV Project                         ***;
*** http://www.systemicpeace.org/polity/polity4.htm         ***;
***                                                         ***;
*** XPOLITY Variable                                        ***;
*** Generated using code from:                              ***;
*** http://www9.georgetown.edu/faculty/jrv24/goldindex.html ***;
*** Accessed 12/14/2010                                     ***;
***************************************************************;

sort numcode year;
by numcode: gen xpolityl = xpolity[_n-1];

save "WarrenTroy.JCR.dta", replace;




