
#########################################################
### NOTE: FOR THIS CODE TO RUN, YOU MUST CHANGE THE   ###
### DIRECTORY LOCATION IN THE NEXT LINE TO THE FOLDER ###
### HOLDING THE UNZIPPED RELICATION DATA FILE         ###
#########################################################

setwd('C:/Projects/WarrenTroyJCR')

library(foreign)
library(mgcv)

#################
### LOAD DATA ### 
#################

iedata <- read.dta("WarrenTroy.JCR.dta")
iedata <- iedata[iedata$gpro_i <= 0.5, ]
iedata <- iedata[iedata$year >= 1990, ]

##########################
### DEFINE SUB-SAMPLES ###
##########################

iedata.dem <- iedata[iedata$xpolityl >= 6, ]
iedata.lang <- iedata[iedata$lang_bin == 1, ]

###############
### TABLE 2 ### 
###############

####################################
### ESTIMATE GAM FOR FULL SAMPLE ### 
### (Model 5)                    ### 
####################################

adata <- iedata

model <- gam(intrawar ~  s(gpro_i, bs="ts", k=15, m=3) +  
                          pcyrs + spline1 + spline2 + spline3, 
                          family=binomial, data=adata)

summary(model)

##########################################
### Generate IV values for predictions ### 
##########################################
predvals <- as.data.frame(matrix(NA,101,1))
names(predvals)[1] <- "gpro_i" 
predvals$gpro_i <- seq(0,0.5,0.005)
predvals$pcyrs <- mean(na.omit(adata$pcyrs))
predvals$spline1 <- mean(na.omit(adata$spline1))
predvals$spline2 <- mean(na.omit(adata$spline2))
predvals$spline3 <- mean(na.omit(adata$spline3))

########################################
### Generate predicted probabilities ### 
########################################
pred <- predict(model, predvals, type="response", se.fit=TRUE)

############################
### Creat Results Matrix ### 
############################
results <- matrix(NA,101,7)
colnames(results) <- c("GroupSize",
                       "prob_all","se_all", 
                       "prob_dem","se_dem", 
                       "prob_lang","se_lang")

#####################
### Store Results ### 
#####################
results[,1] <- predvals$gpro_i
results[,2] <- pred$fit
results[,3] <- pred$se.fit


############################
### DEMOCRACY SUB-SAMPLE ### 
### (Model 6)            ### 
############################

adata <- iedata.dem

model <- gam(intrawar ~  s(gpro_i, bs="ts", k=15, m=3) +  
                          pcyrs + spline1 + spline2 + spline3, 
                          family=binomial, data=adata)

summary(model)

predvals <- as.data.frame(matrix(NA,101,1))
names(predvals)[1] <- "gpro_i" 
predvals$gpro_i <- seq(0,0.5,0.005)
predvals$pcyrs <- mean(na.omit(adata$pcyrs))
predvals$spline1 <- mean(na.omit(adata$spline1))
predvals$spline2 <- mean(na.omit(adata$spline2))
predvals$spline3 <- mean(na.omit(adata$spline3))

pred <- predict(model, predvals, type="response", se.fit=TRUE)

results[,4] <- pred$fit
results[,5] <- pred$se.fit


###########################
### LANGUAGE SUB-SAMPLE ### 
### (Model 7)           ### 
###########################

adata <- iedata.lang

model <- gam(intrawar ~  s(gpro_i, bs="ts", k=15, m=3) +  
                          pcyrs + spline1 + spline2 + spline3, 
                          family=binomial, data=adata)

summary(model)

predvals <- as.data.frame(matrix(NA,101,1))
names(predvals)[1] <- "gpro_i" 
predvals$gpro_i <- seq(0,0.5,0.005)
predvals$pcyrs <- mean(na.omit(adata$pcyrs))
predvals$spline1 <- mean(na.omit(adata$spline1))
predvals$spline2 <- mean(na.omit(adata$spline2))
predvals$spline3 <- mean(na.omit(adata$spline3))

pred <- predict(model, predvals, type="response", se.fit=TRUE)

results[,6] <- pred$fit
results[,7] <- pred$se.fit

results <- as.data.frame(results)

############################
### Results for Figure 4 ### 
############################

write.table(results, file = "WarrenTroy.Figure4.csv", sep = ",", row.names = FALSE)

